[Cmake-commits] CMake branch, next, updated. v2.8.7-2523-g7c20788

Rolf Eike Beer eike at sf-mail.de
Wed Feb 8 14:30:02 EST 2012


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
       via  7c20788c16f5092060d27c3d7741f8685d67ded9 (commit)
       via  bb5f48fe99b3b6d66d7ae6b6c4ae6ac07969e5e2 (commit)
      from  cb4ed0b7994a04f82c14f48edb6c2c7bb2f6a046 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=7c20788c16f5092060d27c3d7741f8685d67ded9
commit 7c20788c16f5092060d27c3d7741f8685d67ded9
Merge: cb4ed0b bb5f48f
Author:     Rolf Eike Beer <eike at sf-mail.de>
AuthorDate: Wed Feb 8 14:29:50 2012 -0500
Commit:     CMake Topic Stage <kwrobot at kitware.com>
CommitDate: Wed Feb 8 14:29:50 2012 -0500

    Merge topic 'PGI-recognise-pgfortran' into next
    
    bb5f48f detect "pgfortran" as PGI Fortran compiler (#12425)


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=bb5f48fe99b3b6d66d7ae6b6c4ae6ac07969e5e2
commit bb5f48fe99b3b6d66d7ae6b6c4ae6ac07969e5e2
Author:     Rolf Eike Beer <eike at sf-mail.de>
AuthorDate: Wed Feb 8 20:26:27 2012 +0100
Commit:     Rolf Eike Beer <eike at sf-mail.de>
CommitDate: Wed Feb 8 20:26:27 2012 +0100

    detect "pgfortran" as PGI Fortran compiler (#12425)
    
    See http://www.pgroup.com/doc/pgiug.pdf, page xviii.

diff --git a/Modules/CMakeDetermineFortranCompiler.cmake b/Modules/CMakeDetermineFortranCompiler.cmake
index efcba29..ade6d58 100644
--- a/Modules/CMakeDetermineFortranCompiler.cmake
+++ b/Modules/CMakeDetermineFortranCompiler.cmake
@@ -50,7 +50,7 @@ IF(NOT CMAKE_Fortran_COMPILER)
     #  fort77: native F77 compiler under HP-UX (and some older Crays)
     #  frt: Fujitsu F77 compiler
     #  pathf90/pathf95/pathf2003: PathScale Fortran compiler
     #  pgf77/pgf90/pgf95: Portland Group F77/F90/F95 compilers
     #  xlf/xlf90/xlf95: IBM (AIX) F77/F90/F95 compilers
     #  lf95: Lahey-Fujitsu F95 compiler
     #  fl32: Microsoft Fortran 77 "PowerStation" compiler
@@ -64,8 +64,8 @@ IF(NOT CMAKE_Fortran_COMPILER)
     #  then 77 or older compilers, gnu is always last in the group,
     #  so if you paid for a compiler it is picked by default.
     SET(CMAKE_Fortran_COMPILER_LIST
-      ifort ifc af95 af90 efc f95 pathf2003 pathf95 pgf95 lf95 xlf95 fort
-      gfortran gfortran-4 g95 f90 pathf90 pgf90 xlf90 epcf90 fort77
+      ifort ifc af95 af90 efc f95 pathf2003 pathf95 pgf95 pgfortran lf95 xlf95
+      fort gfortran gfortran-4 g95 f90 pathf90 pgf90 xlf90 epcf90 fort77
       frt pgf77 xlf fl32 af77 g77 f77
       )
 
@@ -73,7 +73,7 @@ IF(NOT CMAKE_Fortran_COMPILER)
     SET(_Fortran_COMPILER_NAMES_GNU       gfortran gfortran-4 g95 g77)
     SET(_Fortran_COMPILER_NAMES_Intel     ifort ifc efc)
     SET(_Fortran_COMPILER_NAMES_Absoft    af95 af90 af77)
-    SET(_Fortran_COMPILER_NAMES_PGI       pgf95 pgf90 pgf77)
+    SET(_Fortran_COMPILER_NAMES_PGI       pgf95 pgfortran pgf90 pgf77)
     SET(_Fortran_COMPILER_NAMES_PathScale pathf2003 pathf95 pathf90)
     SET(_Fortran_COMPILER_NAMES_XL        xlf)
     SET(_Fortran_COMPILER_NAMES_VisualAge xlf95 xlf90 xlf)

-----------------------------------------------------------------------

Summary of changes:
 Modules/CMakeDetermineFortranCompiler.cmake |    8 ++++----
@@ -50,7 +50,7 @@ IF(NOT CMAKE_Fortran_COMPILER)
     #  frt: Fujitsu F77 compiler
     #  pathf90/pathf95/pathf2003: PathScale Fortran compiler
-    #  pgf77/pgf90/pgf95: Portland Group F77/F90/F95 compilers
+    #  pgf77/pgf90/pgf95/pgfortran: Portland Group F77/F90/F95 compilers
     #  xlf/xlf90/xlf95: IBM (AIX) F77/F90/F95 compilers
     #  lf95: Lahey-Fujitsu F95 compiler
 1 files changed, 4 insertions(+), 4 deletions(-)


hooks/post-receive
-- 
CMake


More information about the Cmake-commits mailing list